import { Component } from '@angular/core';
import { IonApp, IonRouterOutlet } from '@ionic/angular/standalone';
import { Camera } from '@capacitor/camera';
import { Filesystem } from '@capacitor/filesystem';
import Parse from 'parse';
@Component({
  selector: 'app-root',
  standalone: true,
  imports: [
    IonApp,IonRouterOutlet
  ],
  templateUrl: './app.component.html',
  styleUrl: './app.component.scss',
})
export class AppComponent {
  title = 'live-app';
  constructor() {
    this.initParseService();
    this.initDeviceService()
  }
  initParseService() {
    Parse.initialize('ncloudmaster');
    (Parse as any).serverURL = 'https://server.fmode.cn/parse';
    localStorage.setItem('company', 'Qje9D4bqol');
    this.saveParamsInvite();
  }
  saveParamsInvite(){
    let searchParams = this.searchParse()
    let invite = searchParams?.get("invite");
    invite && localStorage.setItem("invite",invite)
  }
  searchParse(url?:string):URLSearchParams{
    url = url || location.href;
    let u = new URL(url);
    return u.searchParams;
  }
  async initDeviceService() {
    try {
      // 请求相机权限
      const cameraPermission = await Camera.requestPermissions();
      if (cameraPermission.camera === 'granted') {
        console.log('相机权限已授予');
      } else {
        console.log('相机权限被拒绝');
      }

      // 请求文件系统权限
      const filesystemPermission = await Filesystem.requestPermissions();
      if (filesystemPermission.publicStorage === 'granted') {
        console.log('文件系统权限已授予');
      } else {
        console.log('文件系统权限被拒绝');
      }
      await this.requestMicrophonePermission()
    } catch (error) {
      console.error('请求权限时出错:', error);
    }
  }
  async requestMicrophonePermission() {
    try {
      const stream = await navigator.mediaDevices.getUserMedia({ audio: true });
      console.log('麦克风权限已授予');
      // 你可以在这里处理音频流
    } catch (error) {
      console.error('麦克风权限被拒绝或请求失败:', error);
    }
  }
}
